@@ -14,7 +14,6 @@ from pydantic.fields import (
     ModelField,
 )
 from pydantic.schema import TypeModelOrEnum
-from pydantic.schema import get_model_name_map as get_model_name_map_pydantic
 
 T = typing.TypeVar("T")
 
@@ -45,12 +44,6 @@ def filter_pydantic_models_from_mapping(
     return {k: m[k] for k in keys}
 
 
-def get_model_name_map(unique_models: typing.Set[type]) -> typing.Dict[type, str]:
-    # this works with any class, but Pydantic types it as if it isn't
-    # if this at some point breaks, we'll just implement it in this function
-    return get_model_name_map_pydantic(unique_models)  # type: ignore[arg-type]
-
-
 def is_sequence_like(field: ModelField) -> bool:
     return field.shape in (
         SHAPE_TUPLE,
@@ -69,13 +62,3 @@ def is_mapping_like(field: ModelField) -> bool:
         or inspect.isclass(field.type_)
         and issubclass(field.type_, BaseModel)
     )
-
-
-class Some(typing.Generic[T]):
-    __slots__ = ("value",)
-
-    def __init__(self, value: T) -> None:
-        self.value = value
-
-    def __repr__(self) -> str:
-        return f"Some({repr(self.value)})"
